Produces a panel of linegraphs showing item thresholds over DIF nodes.
Details
NOTE: only works with PCM data where all variables have multiple thresholds,
since the threshpar() function has problems when dichotomous data are
included.
Produces a panel of linegraphs showing item thresholds over DIF nodes.
NOTE: only works with PCM data where all variables have multiple thresholds,
since the threshpar() function has problems when dichotomous data are
included.