R/dif.R
RIdifFigureLR.Rd
Makes use of the eRm package function LRtest(). Outputs a panel of figures with item average locations and 95% confidence intervals.
LRtest()
RIdifFigureLR(dfin, dif.var)
Dataframe with item data only
DIF variable
DIF variables need to be factors with the same length as the number of rows in the dataset.
sample usage: RIdifTableE(df, dif.age)